==> open-xchange-guard_1.2.0.orig.tar.bz2: open-xchange-guard-1.2.0/com.openexchange.guard/src/com/openexchange/guard/server/DemoClass.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.server;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.guard.config.Config;
import com.openexchange.guard.database.DbCommand;
import com.openexchange.guard.database.DbQuery;
import com.openexchange.guard.util.Core;

public class DemoClass {

    /**
     * Resets/Deletes master keys for email address ONLY FOR USE ON DEMO SERVER
     * 
     * @param request
     * @param response
     * @throws Exception
     */
    public void Reset(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (!Config.demo)
            return;
        String email = request.getParameter("email");
        String command = "SELECT * FROM og_email WHERE email = ? LIMIT 1";
        DbCommand com = new DbCommand(command);
        com.addVariables(email);
        DbQuery dq = new DbQuery();
        dq.readOG(com);
        if (dq.next()) {
            int id = dq.rs.getInt("id");
            int cid = dq.rs.getInt("cid");
            dq.close();
            command = "DELETE FROM og_KeyTable WHERE id = ? AND cid = ?";
            com = new DbCommand(command);
            com.addVariables(id);
            com.addVariables(cid);
            dq = new DbQuery();
            dq.write(com, id, cid);
            dq.close();
            command = "DELETE FROM og_email WHERE id = ? AND cid = ?";
            com = new DbCommand(command);
            com.addVariables(id);
            com.addVariables(cid);
            dq = new DbQuery();
            dq.writeOxGuard(com);
            dq.close();
            Core.sendOK(response, "OK");
            return;
        }
        dq.close();
        Core.sendOK(response, "No");
    }
}

==> open-xchange-guard_2.0.0.orig.tar.bz2: open-xchange-guard-2.0.0/com.openexchange.guard/src/com/openexchange/guard/server/DemoClass.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.server;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.guard.config.Config;
import com.openexchange.guard.database.DbCommand;
import com.openexchange.guard.database.DbQuery;
import com.openexchange.guard.util.Core;

public class DemoClass {

    /**
     * Resets/Deletes master keys for email address ONLY FOR USE ON DEMO SERVER
     * 
     * @param request
     * @param response
     * @throws Exception
     */
    public void Reset(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (!Config.demo)
            return;
        String email = request.getParameter("email");
        String command = "SELECT id, cid FROM og_email WHERE email = ? LIMIT 1";
        DbCommand com = new DbCommand(command);
        com.addVariables(email);
        DbQuery dq = new DbQuery();
        dq.readOG(com);
        if (dq.next()) {
            int id = dq.rs.getInt("id");
            int cid = dq.rs.getInt("cid");
            dq.close();
            command = "DELETE FROM og_KeyTable WHERE id = ? AND cid = ?";
            com = new DbCommand(command);
            com.addVariables(id);
            com.addVariables(cid);
            dq = new DbQuery();
            dq.write(com, id, cid);
            dq.close();
            command = "DELETE FROM og_email WHERE id = ? AND cid = ?";
            com = new DbCommand(command);
            com.addVariables(id);
            com.addVariables(cid);
            dq = new DbQuery();
            dq.writeOxGuard(com);
            dq.close();
            command = "DELETE FROM PGPKeys WHERE email = ?";
            com = new DbCommand(command);
            com.addVariables(email);
            dq = new DbQuery();
            dq.writeOxGuard(com);
            dq.close();
            Core.sendOK(response, "OK");
            return;
        }
        dq.close();
        Core.sendOK(response, "No");
    }
}
